extension LocaleValidation on String {
  /* Regex meaning: 
   *   ^                 match beginning of string
   *   [A-Za-z]{2,4}     match between 2 and 4 characters in the set
   *   (
   *     [_][A-Za-z]{4}  match '_' followed by 4 characters in the set
   *   )?                matches the previous token between zero and one times
   *   (
   *     [_](            match '_' followed by
   *       [A-Za-z]{2}   2 characters in the set
   *       |             or
   *       [0-9]{3}      3 characters in the set
   *     )
   *   )?                matches the previous token between zero and one times
   *   $                 match end of the string
   * 
   * Reference -> https://stackoverflow.com/a/48300605
   * Note      -> Flutter uses '_' and not '-' for locales
   */
  static const _localeRegex =
      '^[A-Za-z]{2,4}([_][A-Za-z]{4})?([_]([A-Za-z]{2}|[0-9]{3}))?\$';

  bool get isValidLocale => RegExp(_localeRegex).hasMatch(this);
}
