import 'package:lokalise_flutter_sdk/src/generator/generator_exception.dart';
import 'package:path/path.dart';
import 'package:yaml/yaml.dart';

class GeneratorConfig {
  static const fileName = 'lok-l10n.yaml';

  static const _defaultClassName = 'Lt';
  static const _defaultMainLocale = 'en';
  static final _defaultOutputDir = join('lib', 'l10n', 'generated');
  static const _defaultOtaEnabled = true;

  final String arbDir;
  final String outputClass;
  final String mainLocale;
  final String outputDir;
  final bool otaEnabled;

  GeneratorConfig._internal({required this.arbDir, String? outputClass})
      : outputClass = outputClass ?? _defaultClassName,
        mainLocale = _defaultMainLocale,
        outputDir = _defaultOutputDir,
        otaEnabled = _defaultOtaEnabled;

  GeneratorConfig.byDefault({required String arbDir})
      : this._internal(arbDir: arbDir);

  static GeneratorConfig fromYml(
      {required String arbDir, required YamlMap yml}) {
    final outputClass = yml['output-class'];
    if (!_isValidClassName(outputClass)) {
      throw GeneratorException('Invalid output-class parameter');
    }

    return GeneratorConfig._internal(arbDir: arbDir, outputClass: outputClass);
  }

  static bool _isValidClassName(String? className) {
    /* Regex meaning: 
    *   ^             match beginning of string
    *   [a-zA-Z]      match a letter for the first char
    *   (?:           start non-capture group
    *   _?            match 0 or 1 '_'
    *   -?            match 0 or 1 '-'
    *   [a-zA-Z0-9]+  match a letter or number, 1 or more times
    *   )*            end non-capture group, match whole group 0 or more times
    */
    return RegExp('^[a-zA-Z](?:_?-?[a-zA-Z0-9]+)*').hasMatch(className ?? '');
  }
}
