import 'package:lokalise_flutter_sdk/src/generator/utils/utils.dart';

import 'label.dart';

/// Template for generated locale file
String generateL10nDartFileContent(
    String className, List<Label> labels, List<String> locales,
    [bool otaEnabled = false]) {
  return """
// GENERATED CODE
//
// After the template files .arb have been changed,
// generate this class by the command in the terminal:
// flutter pub run lokalise_flutter_sdk:gen-lok-l10n
//
// Please see https://pub.dev/packages/lokalise_flutter_sdk

// ignore_for_file: non_constant_identifier_names, lines_longer_than_80_chars
// ignore_for_file: join_return_with_assignment, prefer_final_in_for_each
// ignore_for_file: avoid_redundant_argument_values, avoid_escaping_inner_quotes
// ignore_for_file: depend_on_referenced_packages

import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart';${otaEnabled ? '\n${_generateLokaliseSdkImport()}' : ''}
import 'intl/messages_all.dart';

class $className {
  $className._internal();

  static const LocalizationsDelegate<$className> delegate = _AppLocalizationDelegate();

  static const List<Locale> supportedLocales = [
    ${locales.map((locale) => _generateLocale(locale)).join("\n")}
  ];

  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates =
      <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  static Future<$className> load(Locale locale) {
    final name = (locale.countryCode?.isEmpty ?? false) ? locale.languageCode : locale.toString();
    final localeName = Intl.canonicalizedLocale(name);${otaEnabled ? '\n${_generateMetadataSetter()}' : ''} 
    
    return initializeMessages(localeName).then((_) {
      Intl.defaultLocale = localeName;
      final instance = $className._internal();
      return instance;
    });
  } 

  static $className of(BuildContext context) {
    final instance = Localizations.of<$className>(context, $className);
    assert(instance != null,
        'No instance of $className present in the widget tree. Did you add $className.delegate in localizationsDelegates?');
    return instance!;
  }

  ${otaEnabled ? '\n${_generateMetadata(labels)}\n' : ''}
  ${labels.map((label) => label.generateDartGetter()).join("\n\n")}
}

class _AppLocalizationDelegate extends LocalizationsDelegate<$className> {
  const _AppLocalizationDelegate();

   @override
  bool isSupported(Locale locale) => $className.supportedLocales.any(
      (supportedLocale) => supportedLocale.languageCode == locale.languageCode);

  @override
  Future<$className> load(Locale locale) => $className.load(locale);

  @override
  bool shouldReload(_AppLocalizationDelegate old) => false;
}
"""
      .trim();
}

/// Generate locale
String _generateLocale(String locale) {
  var parts = locale.split('_');

  if (isLangScriptCountryLocale(locale)) {
    return '      Locale.fromSubtags(languageCode: \'${parts[0]}\', scriptCode: \'${parts[1]}\', countryCode: \'${parts[2]}\'),';
  } else if (isLangScriptLocale(locale)) {
    return '      Locale.fromSubtags(languageCode: \'${parts[0]}\', scriptCode: \'${parts[1]}\'),';
  } else if (isLangCountryLocale(locale)) {
    return '      Locale.fromSubtags(languageCode: \'${parts[0]}\', countryCode: \'${parts[1]}\'),';
  } else {
    return '      Locale.fromSubtags(languageCode: \'${parts[0]}\'),';
  }
}

/// Generate Lokalise package import
String _generateLokaliseSdkImport() {
  return "import 'package:lokalise_flutter_sdk/lokalise_flutter_sdk.dart';";
}

/// Generate cache data setter
String _generateMetadataSetter() {
  return '  Lokalise.instance.metadata = _metadata;';
}

/// Generate data cache
String _generateMetadata(List<Label> labels) {
  return [
    '  static final Map<String, List<String>> _metadata = {',
    labels.map((label) => label.generateMetadata()).join(',\n'),
    '  };'
  ].join('\n');
}
