import 'package:lokalise_flutter_sdk/src/ota/data/api/clients/ota/response/error/ota_error_info.dart';
import 'package:lokalise_flutter_sdk/src/ota/domain/exceptions/validation_exception.dart';
import 'package:lokalise_flutter_sdk/src/ota/domain/models/validation_error.dart';

class OtaErrorResponse {
  final int statusCode;
  final String message;
  final List<OtaErrorInfo> errors;

  OtaErrorResponse({
    required this.statusCode,
    required this.message,
    required this.errors,
  });

  factory OtaErrorResponse.fromJson({required Map<String, dynamic> json}) {
    _validateJson(json);

    return OtaErrorResponse(
      statusCode: json['statusCode'] as int,
      message: json['message'] as String,
      errors: (json['error'] as List)
          .map((e) => OtaErrorInfo.fromJson(json: e))
          .toList(),
    );
  }

  static void _validateJson(Map<String, dynamic> json) {
    final List<ValidationError> errors = [];

    if (json['statusCode'] is! int) {
      errors.add(ValidationError(
        type: OtaErrorResponse,
        path: 'statusCode',
        received: json['statusCode'],
        expectedType: int,
      ));
    }

    if (json['message'] is! String) {
      errors.add(ValidationError(
        type: OtaErrorResponse,
        path: 'message',
        received: json['message'],
        expectedType: int,
      ));
    }

    if (json['error'] is! List) {
      errors.add(ValidationError(
        type: OtaErrorResponse,
        path: 'error',
        received: json['error'],
        expectedType: List,
      ));
    }

    if (errors.isNotEmpty) {
      throw ValidationException(errors: errors);
    }
  }
}
