import 'package:archive/archive_io.dart';
import 'package:lokalise_flutter_sdk/src/ota/data/api/clients/ota/response/error/ota_error_response.dart';
import 'package:lokalise_flutter_sdk/src/ota/data/api/exceptions/api_exception.dart';

class InternalException<T> implements Exception {
  static const otaApiError = 'ota_api_error';
  static const bundleEmptyError = 'bundle_empty_error';
  static const bundleFormatError = 'bundle_format_error';
  static const unexpectedError = 'unexpected_error';

  final String code;
  final T param;

  InternalException({required this.code, required this.param});

  static InternalException<ApiException> fromApiException({
    required ApiException param,
  }) =>
      InternalException(code: otaApiError, param: param);

  static InternalException<OtaErrorResponse> fromOtaErrorResponse({
    required OtaErrorResponse param,
  }) =>
      InternalException(code: otaApiError, param: param);

  static InternalException<String> bundleEmpty() => InternalException(
        code: bundleEmptyError,
        param: 'The remote bundle is empty',
      );

  static InternalException<Archive> bundleFormat({
    required Archive param,
  }) =>
      InternalException(
        code: bundleFormatError,
        param: param,
      );

  static InternalException<String> unexpected({
    required String param,
  }) =>
      InternalException(code: unexpectedError, param: param);
}
