import 'package:flutter/foundation.dart';
import 'package:lokalise_flutter_sdk/src/constants.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'dart:io';

class DeviceInfo {
  final PackageInfo _packageInfo;
  String _appVersion;

  DeviceInfo({
    required PackageInfo packageInfo,
    required String appVersion,
  })  : _packageInfo = packageInfo,
        _appVersion = appVersion;

  String get appVersion {
    if (_appVersion.trim().isEmpty) {
      _appVersion = _standardizeVersion(_packageInfo.version);
    }
    return _appVersion;
  }

  String get packageName => _packageInfo.packageName;

  String get platform => kIsWeb ? 'web' : Platform.operatingSystem;

  String get lokaliseSdkVersion => kLokaliseSdkVersion;

  String _standardizeVersion(String version) {
    if (version.contains('-')) {
      return _standardizeVersion(version.split('-').first);
    }

    if (version.contains('+')) {
      return _standardizeVersion(version.split('+').first);
    }

    return version;
  }
}
