import 'package:flutter_test/flutter_test.dart';
import 'package:lokalise_flutter_sdk/src/extensions/string_locale.dart';

void main() {
  group('String locale extension - LocaleValidation', () {
    test('invalid locales', () async {
      const invalidLocales = [
        '',
        'custom',
        'custom_1',
        'this_is_my_locale',
        'en-US',
        'en-004',
        'zh-Hant_HK',
        'zh_Hant-HK',
      ];

      for (var locale in invalidLocales) {
        expect(locale.isValidLocale, false, reason: 'Failing with: $locale');
      }
    });

    test('valid locales', () async {
      const locales = [
        // Only language codes
        'es',
        'pt',
        'en',
        'lv',
        'zh', // Chinese
        'shi', // Tachelhit

        // lang codes + country code
        'es_FR',
        'en_US',
        'pt_BR',
        'lv_LV',
        'shi_MA',
        'zh_Hans',
        'zh_Hant',
        'shi_Tfng',
        'sHi_TfNg',
        'zh_SG',
        'es_419',
        'en_004',

        // lang codes + country code + script code
        'zh_Hant_HK',
        'zh_Hant_CN',
        'zh_Hant_MO',
        'shi_Tfng_MA',
      ];

      for (var locale in locales) {
        expect(locale.isValidLocale, true, reason: 'Failing with: $locale');
      }
    });
  });
}
