import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:lokalise_flutter_sdk/src/ota/helpers/initializer.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:shared_preferences/shared_preferences.dart';

void main() {
  setUp(() {
    WidgetsFlutterBinding.ensureInitialized();
    SharedPreferences.setMockInitialValues({});
    PackageInfo.setMockInitialValues(
      appName: 'test',
      packageName: 'test',
      version: '1.0.0',
      buildNumber: 'test',
      buildSignature: 'test',
      installerStore: 'test',
    );
  });

  group('Initializer', () {
    test('works - version provided', () async {
      final initializer = Initializer(
        projectId: 'test-projectId',
        sdkToken: 'test-token',
        appVersion: '1.0.0',
        preRelease: true,
      );
      final instance = await initializer.lokalise;
      expect(instance, isNotNull);
    });

    test('works - version empty', () async {
      final initializer = Initializer(
        projectId: 'test-projectId',
        sdkToken: 'test-token',
        appVersion: '',
        preRelease: true,
      );
      final instance = await initializer.lokalise;
      expect(instance, isNotNull);
    });
  });
}
